]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - sync.sh
lib.sh: m4() define useful macros.
[config/dotfiles.git] / sync.sh
diff --git a/sync.sh b/sync.sh
index 55791c10e28ad475ae51e733917ee80c85c4e013..a3f9eaf124ffc324b942582a7e30ff2736fddcb2 100755 (executable)
--- a/sync.sh
+++ b/sync.sh
@@ -5,31 +5,49 @@
 # Allows fetching (no merge) and pushing at the moment.
 
 
-# Select the method, fetch and push is possible.
-if [ x$1 = x -o x$1 = xfetch -o x$1 = xfe ]; then
+# Select the method: fetch, push and status is possible.
+if [ x$1 = x -o x$1 = xstatus -o x$1 = xst ]; then
+    method=status
+elif [ $1 = fetch -o $1 = fe ]; then
     method=fetch
 elif [ $1 = push -o $1 = pu ]; then
     method=push
 else
-    echo "Usage: sync.sh [fetch | fe | push | pu ]"
+    echo "Usage: sync.sh [fetch | fe | push | pu | status | st]"
     echo
     echo "fetch: Fetch from all remotes."
     echo "push: Push to all remotes."
+    echo "status: Display status for all git repositories."
     exit 1
 fi
 
# Fetch from/Push to each remote of each git subdirectory.
 for project in `find . -name .git -type d`; do
-    if [ -d "$project" ]; then
-        pwd=`pwd`
-        cd "$project"
+    pwd=`pwd`
+    cd "$project"
 
-        # Fetch from/Push to all remotes.
+    # Remove .git from repository name.
+    project=`echo "$project" | sed "s|.git||"`
+
+    # Display all commits not in the master branch.
+    if [ $method = status ]; then
+        output=`git log --graph --all --pretty=oneline --color master..`
+        if [ "x$output" != x ]; then
+            echo "$project status:"
+            echo "$output"
+        fi
+    # Fetch from/Push to all remotes.
+    else
         for remote in `git remote`; do
             echo "$project: ${method}ing $remote ..."
             git $method "$remote"
         done
-
-        cd "$pwd"
     fi
+
+    cd "$pwd"
 done
+
+# Run status after a fetch to see new changes.
+if [ $method = fetch ]; then
+    ./sync.sh status
+fi
@@ -5,31 +5,49 @@
 fi
 
-# Fetch from/Push to each remote of each git subdirectory.
+# Execute the given method for each git subdirectory.
 for project in `find . -name .git -type d`; do